#!/bin/bash
gmt gmtset PS_MEDIA letter
gmt gmtset PROJ_LENGTH_UNIT cm
gmt gmtset FORMAT_GEO_MAP D
gmt gmtset PS_PAGE_ORIENTATION portrait
psfile=jamaica2.22_base.ps
projection=-JM16.0c+
region=-R-78.9/-75.8/17.6/18.5
gmt psbasemap $region $projection -Bxa1.0f0.1 -Bya1.0f0.1 -BWeSn+t'Base Map jamaica2.22' -K > $psfile

# Standard Topography (ETOPO1)
palette=-Ctables/gmt/cpt/topo.cpt
gmt grdcut @earth_relief_01m_g -Gmloc.grd $region
gmt grdgradient mloc.grd -Gmloc_ilum.grd -A340 -Nt
gmt grdimage mloc.grd $palette $projection -Imloc_ilum.grd -O -K >> $psfile
rm mloc.grd mloc_ilum.grd

# Coastlines and rivers
gmt pscoast $projection $region -Df -Ia/blue -Wblue -O -K >> $psfile

# Event numbers
gmt psxy -: -R $projection -Sl8p+t"1" -G0 -O -K << END >> $psfile
    17.698   -78.791
END
gmt psxy -: -R $projection -Sl8p+t"2" -G0 -O -K << END >> $psfile
    18.178   -76.553
END
gmt psxy -: -R $projection -Sl8p+t"3" -G0 -O -K << END >> $psfile
    18.231   -76.596
END
gmt psxy -: -R $projection -Sl8p+t"4" -G0 -O -K << END >> $psfile
    18.098   -76.677
END
gmt psxy -: -R $projection -Sl8p+t"5" -G0 -O -K << END >> $psfile
    17.696   -78.814
END
gmt psxy -: -R $projection -Sl8p+t"6" -G0 -O -K << END >> $psfile
    17.943   -78.018
END
gmt psxy -: -R $projection -Sl8p+t"7" -G0 -O -K << END >> $psfile
    18.181   -76.650
END
gmt psxy -: -R $projection -Sl8p+t"8" -G0 -O -K << END >> $psfile
    18.185   -76.695
END
gmt psxy -: -R $projection -Sl8p+t"9" -G0 -O -K << END >> $psfile
    18.331   -77.669
END
gmt psxy -: -R $projection -Sl8p+t"10" -G0 -O -K << END >> $psfile
    17.993   -76.577
END
gmt psxy -: -R $projection -Sl8p+t"11" -G0 -O -K << END >> $psfile
    18.257   -77.435
END
gmt psxy -: -R $projection -Sl8p+t"12" -G0 -O -K << END >> $psfile
    18.039   -78.211
END
gmt psxy -: -R $projection -Sl8p+t"13" -G0 -O -K << END >> $psfile
    18.064   -76.823
END
gmt psxy -: -R $projection -Sl8p+t"14" -G0 -O -K << END >> $psfile
    18.070   -76.698
END
gmt psxy -: -R $projection -Sl8p+t"15" -G0 -O -K << END >> $psfile
    17.846   -77.849
END
gmt psxy -: -R $projection -Sl8p+t"16" -G0 -O -K << END >> $psfile
    17.703   -78.803
END
gmt psxy -: -R $projection -Sl8p+t"17" -G0 -O -K << END >> $psfile
    18.098   -77.970
END
gmt psxy -: -R $projection -Sl8p+t"18" -G0 -O -K << END >> $psfile
    18.104   -78.207
END
gmt psxy -: -R $projection -Sl8p+t"19" -G0 -O -K << END >> $psfile
    18.049   -75.901
END
gmt psxy -: -R $projection -Sl8p+t"20" -G0 -O -K << END >> $psfile
    18.101   -77.353
END
gmt psxy -: -R $projection -Sl8p+t"21" -G0 -O -K << END >> $psfile
    18.066   -76.679
END
gmt psxy -: -R $projection -Sl8p+t"22" -G0 -O -K << END >> $psfile
    18.104   -76.960
END
gmt psxy -: -R $projection -Sl8p+t"23" -G0 -O -K << END >> $psfile
    18.062   -76.637
END
gmt psxy -: -R $projection -Sl8p+t"24" -G0 -O -K << END >> $psfile
    18.094   -76.713
END
gmt psxy -: -R $projection -Sl8p+t"25" -G0 -O -K << END >> $psfile
    18.216   -77.053
END
gmt psxy -: -R $projection -Sl8p+t"26" -G0 -O -K << END >> $psfile
    18.123   -76.740
END
gmt psxy -: -R $projection -Sl8p+t"27" -G0 -O -K << END >> $psfile
    18.077   -77.703
END
gmt psxy -: -R $projection -Sl8p+t"28" -G0 -O -K << END >> $psfile
    18.044   -77.522
END
gmt psxy -: -R $projection -Sl8p+t"29" -G0 -O -K << END >> $psfile
    18.125   -77.415
END
gmt psxy -: -R $projection -Sl8p+t"30" -G0 -O -K << END >> $psfile
    18.137   -76.683
END
gmt psxy -: -R $projection -Sl8p+t"31" -G0 -O -K << END >> $psfile
    17.791   -77.327
END
gmt psxy -: -R $projection -Sl8p+t"32" -G0 -O -K << END >> $psfile
    18.269   -76.862
END
gmt psxy -: -R $projection -Sl8p+t"33" -G0 -O -K << END >> $psfile
    18.118   -77.448
END
gmt psxy -: -R $projection -Sl8p+t"34" -G0 -O -K << END >> $psfile
    18.137   -77.411
END
gmt psxy -: -R $projection -Sl8p+t"35" -G0 -O -K << END >> $psfile
    18.218   -77.763
END
gmt psxy -: -R $projection -Sl8p+t"36" -G0 -O -K << END >> $psfile
    18.099   -77.269
END
gmt psxy -: -R $projection -Sl8p+t"37" -G0 -O -K << END >> $psfile
    18.360   -76.545
END
gmt psxy -: -R $projection -Sl8p+t"38" -G0 -O -K << END >> $psfile
    17.852   -76.552
END
gmt psxy -: -R $projection -Sl8p+t"39" -G0 -O -K << END >> $psfile
    18.184   -77.792
END
gmt psxy -: -R $projection -Sl8p+t"40" -G0 -O -K << END >> $psfile
    18.445   -77.654
END
gmt psxy -: -R $projection -Sl8p+t"41" -G0 -O -K << END >> $psfile
    18.124   -76.991
END
gmt psxy -: -R $projection -Sl8p+t"42" -G0 -O -K << END >> $psfile
    18.112   -76.696
END
gmt psxy -: -R $projection -Sl8p+t"43" -G0 -O -K << END >> $psfile
    18.105   -76.631
END
gmt psxy -: -R $projection -Sl8p+t"44" -G0 -O -K << END >> $psfile
    18.127   -76.622
END
gmt psxy -: -R $projection -Sl8p+t"45" -G0 -O -K << END >> $psfile
    18.107   -76.614
END
gmt psxy -: -R $projection -Sl8p+t"46" -G0 -O -K << END >> $psfile
    18.148   -76.642
END
gmt psxy -: -R $projection -Sl8p+t"47" -G0 -O -K << END >> $psfile
    18.123   -76.820
END

# Change in location, calibration shift if available
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    17.707   -78.803
    17.698   -78.791
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    17.707   -78.819
    17.698   -78.791
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.186   -76.561
    18.178   -76.553
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.243   -76.476
    18.178   -76.553
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.237   -76.601
    18.231   -76.596
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.145   -76.474
    18.231   -76.596
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.106   -76.682
    18.098   -76.677
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    17.937   -76.576
    18.098   -76.677
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    17.693   -78.819
    17.696   -78.814
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    17.605   -78.804
    17.696   -78.814
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    17.924   -78.044
    17.943   -78.018
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.004   -78.013
    17.943   -78.018
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.185   -76.652
    18.181   -76.650
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.042   -76.561
    18.181   -76.650
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.191   -76.697
    18.185   -76.695
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.159   -76.638
    18.185   -76.695
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.330   -77.671
    18.331   -77.669
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.413   -77.589
    18.331   -77.669
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    17.999   -76.562
    17.993   -76.577
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    17.925   -76.476
    17.993   -76.577
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.260   -77.438
    18.257   -77.435
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.299   -77.377
    18.257   -77.435
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.035   -78.211
    18.039   -78.211
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.164   -78.106
    18.039   -78.211
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.064   -76.825
    18.064   -76.823
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.022   -76.780
    18.064   -76.823
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.072   -76.699
    18.070   -76.698
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.042   -76.633
    18.070   -76.698
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    17.846   -77.851
    17.846   -77.849
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    17.906   -77.926
    17.846   -77.849
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    17.703   -78.803
    17.703   -78.803
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    17.766   -78.759
    17.703   -78.803
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.099   -77.968
    18.098   -77.970
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.185   -77.945
    18.098   -77.970
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.082   -78.219
    18.104   -78.207
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.156   -78.139
    18.104   -78.207
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.049   -75.904
    18.049   -75.901
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.264   -75.910
    18.049   -75.901
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.099   -77.355
    18.101   -77.353
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.152   -77.373
    18.101   -77.353
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.067   -76.683
    18.066   -76.679
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.232   -76.639
    18.066   -76.679
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.105   -76.962
    18.104   -76.960
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.233   -76.916
    18.104   -76.960
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.063   -76.639
    18.062   -76.637
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.229   -76.576
    18.062   -76.637
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.094   -76.717
    18.094   -76.713
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.354   -76.671
    18.094   -76.713
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.218   -77.054
    18.216   -77.053
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.334   -77.017
    18.216   -77.053
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.125   -76.741
    18.123   -76.740
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.181   -76.675
    18.123   -76.740
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.092   -77.706
    18.077   -77.703
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.091   -77.722
    18.077   -77.703
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.043   -77.525
    18.044   -77.522
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.069   -77.541
    18.044   -77.522
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.124   -77.417
    18.125   -77.415
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.111   -77.419
    18.125   -77.415
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.139   -76.687
    18.137   -76.683
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.280   -76.704
    18.137   -76.683
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    17.783   -77.333
    17.791   -77.327
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    17.885   -77.277
    17.791   -77.327
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.265   -76.863
    18.269   -76.862
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.416   -76.798
    18.269   -76.862
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.116   -77.451
    18.118   -77.448
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.141   -77.494
    18.118   -77.448
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.135   -77.413
    18.137   -77.411
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.140   -77.429
    18.137   -77.411
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.212   -77.766
    18.218   -77.763
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.205   -77.869
    18.218   -77.763
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.097   -77.272
    18.099   -77.269
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.070   -77.306
    18.099   -77.269
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.362   -76.549
    18.360   -76.545
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.300   -76.597
    18.360   -76.545
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    17.851   -76.554
    17.852   -76.552
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    17.915   -76.497
    17.852   -76.552
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.180   -77.795
    18.184   -77.792
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.257   -77.814
    18.184   -77.792
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.441   -77.659
    18.445   -77.654
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.476   -77.697
    18.445   -77.654
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.146   -76.973
    18.124   -76.991
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.037   -76.726
    18.124   -76.991
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.112   -76.698
    18.112   -76.696
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.146   -76.650
    18.112   -76.696
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.106   -76.633
    18.105   -76.631
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.190   -76.607
    18.105   -76.631
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.129   -76.627
    18.127   -76.622
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.302   -76.664
    18.127   -76.622
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.107   -76.616
    18.107   -76.614
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.212   -76.583
    18.107   -76.614
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.148   -76.645
    18.148   -76.642
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.256   -76.615
    18.148   -76.642
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    18.125   -76.825
    18.123   -76.820
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    18.143   -76.759
    18.123   -76.820
END

# Confidence ellipses for relative location
gmt psxy -: -R $projection -SE -Wthick -O -K << END >> $psfile
    17.698   -78.791   -24.252     3.556     4.767
    18.178   -76.553    47.918     2.955     3.001
    18.231   -76.596    46.227     2.039     2.298
    18.098   -76.677    82.903     1.739     1.931
    17.696   -78.814   -75.673     3.248     4.905
    17.943   -78.018   -39.691     3.578     6.995
    18.181   -76.650   -83.253     1.846     3.156
    18.185   -76.695   -77.088     3.128     5.993
    18.331   -77.669   -58.659     3.585     4.874
    17.993   -76.577   -57.988     3.481     4.776
    18.257   -77.435   -22.913     1.393     2.046
    18.039   -78.211   -62.370     3.833     5.768
    18.064   -76.823    80.597     2.216     3.263
    18.070   -76.698   -78.975     1.490     1.835
    17.846   -77.849   -69.273     2.300     4.074
    17.703   -78.803   -86.826     2.049     3.205
    18.098   -77.970   -79.378     2.076     2.477
    18.104   -78.207   -71.431     4.111     7.154
    18.049   -75.901    23.901     4.117     4.456
    18.101   -77.353    71.480     2.937     3.258
    18.066   -76.679    -1.402     2.251     2.798
    18.104   -76.960    82.110     1.763     2.763
    18.062   -76.637    80.386     1.954     2.823
    18.094   -76.713    36.390     3.510     5.041
    18.216   -77.053    69.161     1.915     4.187
    18.123   -76.740    26.024     1.759     2.093
    18.077   -77.703    72.995     3.724     5.189
    18.044   -77.522   -29.275     2.014     3.096
    18.125   -77.415   -47.300     1.705     2.247
    18.137   -76.683    71.466     3.470     4.454
    17.791   -77.327   -72.974     2.723     4.556
    18.269   -76.862    59.785     1.705     2.788
    18.118   -77.448   -21.208     1.600     1.935
    18.137   -77.411   -36.135     2.261     2.767
    18.218   -77.763   -43.649     2.422     4.079
    18.099   -77.269    -8.729     1.550     2.096
    18.360   -76.545    41.893     1.758     4.810
    17.852   -76.552    87.075     1.751     2.134
    18.184   -77.792   -33.153     2.797     4.795
    18.445   -77.654    -1.129     2.583     3.956
    18.124   -76.991   -78.780     0.376     8.232
    18.112   -76.696   -11.660     2.023     2.255
    18.105   -76.631    74.434     1.280     1.706
    18.127   -76.622    66.889     3.277     4.244
    18.107   -76.614    57.345     1.619     2.709
    18.148   -76.642    73.536     2.037     2.889
    18.123   -76.820   -61.020     3.312     4.209
END

# Hypocentroid confidence ellipse
gmt psxy -: -R $projection -SE -Wthick,blue -O -K << END >> $psfile
    17.647   -78.863   -85.121     1.211     2.300
END
gmt pstext -: -R $projection -F+f6p,Helvetica,blue+a0.+jBL -O -K << END >> $psfile
    17.647   -78.840   Hypocentroid
END

# Circle of radius 5 km for reference
gmt psxy -: -R $projection -SE -Wthick,red -O -K << END >> $psfile
    17.647   -78.863     0.000    10.000    10.000
END
gmt psxy -: -R $projection -Sx -Wthinnest,blue -O -K << END >> $psfile
    17.647   -78.863     0.070
END
gmt pstext -: -R $projection -F+f6p,Helvetica-Bold,red+a0.+jBC -Gwhite -O << END >> $psfile
    17.602   -78.863   5 km
END
